components/components library

Classes

FlutterNostrFeed
FlutterNostrFeedList
OneTimeEventBuilder
A widget that fetches a single event from Nostr relays once and provides it to a builder function.
OneTimeEventsBuilder
A widget that fetches events from Nostr relays once and provides them to a builder function.