AuthSession class

Annotations
  • @Collection.new()

Constructors

AuthSession({required String id, required String pubkey, required AuthType type, required DateTime createdAt, String? privateKey, String? bunkerUrl, String? token})
AuthSession.fromJson(Map<String, dynamic> json)
factory

Properties

bunkerUrl String?
final
canSign bool
no setter
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isarId int
no setter
privateKey String?
final
pubkey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String?
final
type AuthType
final

Methods

createEvent({required int kind, required String content, List<List<String>>? tags, DateTime? createdAt}) Future<NostrEvent>
fastHash(String string) int
Simple string-based unique hashing for Isar
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited