EventsRequestResponse class

Implementers

Constructors

EventsRequestResponse({required String subscriptionId, required List<NostrFilter> filters, required List<NostrEvent> events, required DateTime requestTime})
const

Properties

events List<NostrEvent>
final
filters List<NostrFilter>
final
hashCode int
The hash code for this object.
no setterinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
requestTime DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
subscriptionId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited