ParallelEventsRequestResponse<T> class
- Inheritance
-
- Object
- EventsRequestResponse
- ParallelEventsRequestResponse
Constructors
-
ParallelEventsRequestResponse({required String subscriptionId, required List<
NostrFilter> filters, required List<NostrEvent> events, required DateTime requestTime, required List<T> adaptedResults, Object? error}) -
const
- ParallelEventsRequestResponse.error({required Object error})
-
factory
Properties
-
adaptedResults
→ List<
T> -
final
- error → Object?
-
final
-
events
→ List<
NostrEvent> -
finalinherited
-
filters
→ List<
NostrFilter> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- requestTime → DateTime
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - subscriptionId → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited