NostrAuthKeysTransformer class

Constructors

NostrAuthKeysTransformer({required String npubToPubkey(String npub), required String pubkeyToNpub(String pubkey), required String privateKeyToNsec(String privateKey), required String nsecToPrivateKey(String nsec)})

Properties

hashCode int
The hash code for this object.
no setterinherited
npubToPubkey String Function(String npub)
final
nsecToPrivateKey String Function(String nsec)
final
privateKeyToNsec String Function(String privateKey)
final
pubkeyToNpub String Function(String pubkey)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited