NostrService class
Properties
- connectionTimeout → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nostrInstance ↔ Nostr
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendEventTimeout → Duration
-
final
Methods
-
connect(
{required List< String> relays}) → Future<void> -
createSignedEvent(
{required int kind, required String privateKey, String? content, List< List< ? tags, DateTime? createdAt}) → NostrEventString> > -
generateNewKeysPair(
) → NostrAuthKeys -
getEvents(
{required List< NostrFilter> filters}) → Future<(String?, List< NostrEvent> )> -
getPublicKeyFromKeysPair(
NostrAuthKeys keysPair) → String -
getPublicKeyFromPrivateKey(
String privateKey) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
npubToPubkey(
String npub) → String -
nsecToPrivateKey(
String nsec) → String -
privateKeyToNsec(
String privateKey) → String -
pubkeyToNpub(
String pubkey) → String -
reconnect(
) → Future< void> -
sendEvent(
NostrEvent event) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → NostrService
-
final