FlutterNostrFeedBuilderData<T> class
Constructors
-
FlutterNostrFeedBuilderData({required bool isLoading, required int iterativeRequestCount, required String? error, Map<
String, List< ? parallelRequestResults = const {}, List<ParallelEventsRequestResponse> >EventsRequestResponse> eventRequestResponseEntries = const []}) -
const
Properties
- error → String?
-
final
-
eventRequestResponseEntries
→ List<
EventsRequestResponse> -
final
-
events
→ List<
NostrEvent> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLoading → bool
-
final
- iterativeRequestCount → int
-
final
-
parallelRequestResults
→ Map<
String, List< ?ParallelEventsRequestResponse> > -
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parallelRequestResultsFor<
R> (ParallelRequestId< R> requestId) → List<ParallelEventsRequestResponse< ?R> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited