next property
Build the next request using the results of this step. If provided, it will be invoked with the full List
Implementation
final ParallelRequest<dynamic> Function(List<dynamic> previousResults)? next;
Build the next request using the results of this step. If provided, it will be invoked with the full List
final ParallelRequest<dynamic> Function(List<dynamic> previousResults)? next;